# These tiny utilities can be compiled staticly if desired
%define usedietlibc %{?_without_dietlibc: 0} %{?!_without_dietlibc: 1}

Name:    daemontools
Version: 0.76
Release: 16%{?dist}
Summary: a collection of tools for managing UNIX services

Group:   System Environment/Daemons
License: Public Domain
URL:     http://cr.yp.to/%{name}.html
Source0: http://cr.yp.to/%{name}/%{name}-%{version}.tar.gz
Source1: http://smarden.org/pape/djb/manpages/%{name}-%{version}-man.tar.gz
Source2: daemontools.svscan.init
Source3: daemontools.svscan.sysconfig
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires(post): chkconfig
Requires(preun): chkconfig, initscripts
Provides: svscan%{?_isa} = %{name}-%{release}, supervise%{?_isa} = %{name}-%{release}
%if %{?usedietlibc}
BuildRequires: dietlibc
%endif


# DJB wonkiness
Patch0: http://www.qmail.org/moni.csi.hu/pub/glibc-2.3.1/daemontools-0.76.errno.patch

# Remove references to /command hardcoded into svscanboot 
# (even though we don't use svscanboot in this package). Then
# have it examine /var/svscan by default instead of /service
Patch1: daemontools-0.76.no-command-dir.patch
Patch2: daemontools-0.76.var-svscan.patch


%description
A set of command-line tools for starting and stopping services, setting
environment variables, and dropping privileges via exec chains, and 
logging output. It also includes filters for reading TAI64 output.

Most DJB software (such as ucspi-tcp) is written with this toolset in mind.

This includes the supervice and svscan tools, configured with a master 
SysVInit script (much like xinetd is).

Includes man pages by Gerrit Pape.


%prep
%setup -q -n admin
%setup -q -D -T -a 1 -n admin
%patch0 -b .errno-fix
%patch1 -b .no-command-dir
%patch2 -b .var-svscan


%build
cd %{name}-%{version}
%if %{?usedietlibc}
  echo "diet -v -Os gcc %{optflags} -DREALLY_SMALL -finline-functions -g -Wall -Os"             > conf-cc
  echo "diet -v -Os gcc %{optflags} -DREALLY_SMALL -finline-functions -g -Wall -Os -static -s"  > conf-ld
%endif


. package/compile


%install
rm -fR %{buildroot}

install -d %{buildroot}/sbin
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_initrddir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_localstatedir}/svscan

install -m 755 %{name}-%{version}/command/* %{buildroot}/sbin/
install -m 755 %{SOURCE2} %{buildroot}%{_initrddir}/svscan
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/svscan

pushd %{buildroot}/sbin
   for i in *; do
       %{__ln_s} "/sbin/$i" "%{buildroot}%{_sbindir}/$i"
   done
popd

%{__ln_s} %{_initrddir}/svscan     %{buildroot}/sbin/svscanctl
%{__ln_s} %{_localstatedir}/svscan %{buildroot}/service
%{__ln_s} %{_localstatedir}/svscan %{buildroot}%{_sysconfdir}/service
%{__ln_s} %{_localstatedir}/svscan %{buildroot}%{_localstatedir}/service

install -d %{buildroot}%{_mandir}/man8
install -m 644 %{name}-man/*.8 %{buildroot}%{_mandir}/man8/
install %{name}-man/README README.man


%clean
rm -fR %{buildroot}

%pre
# Check for upgrade
rm -f /tmp/%{name}.upgrade.restart /tmp/%{name}.upgrade.finish

if [ "$1" -gt 1 ]; then
   for legacy in /etc/service /var/service /service
   do
      if [ -n "$legacy" -a -d "$legacy" -a ! -L "$legacy" ]; then
	# upgrading from $legacy somewhere
	touch /tmp/%{name}.upgrade.finish
	/sbin/service svscan status >/dev/null && touch /tmp/%{name}.upgrade.restart
        /sbin/service svscan stop >/dev/null 2>&1

	# move supervise links to new location
	mkdir -p "%{_localstatedir}/%{name}.temp/"
	mv $legacy/* "%{_localstatedir}/%{name}.temp/"	|| :

	# directory should be empty now... if not, error out
	rmdir "$legacy"

        %{__perl} -pi -e "s#=\"$legacy\"#=\"%{_localstatedir}/svscan\"#" %{_sysconfdir}/sysconfig/svscan
     fi
   done
fi

%post
/sbin/chkconfig --add svscan 			|| :

if [ -e "/tmp/%{name}.upgrade.finish" ] ; then
   # move stuff back
   mv %{_localstatedir}/%{name}.temp/* %{_localstatedir}/svscan/	|| :
   rmdir "%{_localstatedir}/%{name}.temp/"
   rm -f "/tmp/%{name}.upgrade.finish"
fi

if [ -e "/tmp/%{name}.upgrade.restart" ] ; then
   rm -f "/tmp/%{name}.upgrade.restart"
   /sbin/service svscan start >/dev/null	|| :
else
   /sbin/service svscan condrestart >/dev/null	|| :
fi

exit 0

%preun
if [ "$1" -eq 0 ]; then
    /sbin/service svscan stop >/dev/null	|| :
    /sbin/chkconfig --del svscan		|| :
fi


%files
%defattr(-,root,root)
%doc %{name}-%{version}/src/TODO
%doc %{name}-%{version}/src/CHANGES
%doc %{name}-%{version}/package/README*
%doc README.man

%{_initrddir}/svscan
%{_sbindir}/*
/sbin/*

%attr(755,root,root) %dir %{_localstatedir}/svscan
%attr(755,root,root) /service
%attr(755,root,root) %{_sysconfdir}/service
%attr(755,root,root) %{_localstatedir}/service

%config %{_sysconfdir}/sysconfig/svscan
%{_mandir}/*/*


%changelog
* Mon Sep 30 2013 Japheth Cleaver <cleaver@terabithia.org> 0.76-16
- rebuild with updated dietlibc

* Fri Mar 04 2011 Japheth Cleaver <cleaver@terabithia.org> 0.76-15
- rebuild with updated dietlibc
- spec file cleanup

* Fri Mar 04 2011 Japheth Cleaver <jcleaver@soe.sony.com> 0.76-14
- rebuild with updated dietlibc
- move /var/service to /var/svscan, maintain legacy symlinks
- stop and restart during an upgrade

* Fri Jun 04 2010 Japheth Cleaver <jcleaver@soe.sony.com> 0.76-13
- add explicit chkconfig add to post-install
- static build optional

* Mon May 03 2010 Japheth Cleaver <jcleaver@soe.sony.com> 0.76-12
- rebuilt for rhel6 beta
- remove legacy upgrade logic from scriptlets

* Wed Nov 19 2008 Japheth Cleaver <jcleaver@soe.sony.com> 0.76-11
- rebuilt

* Tue Oct 17 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-10
- built statically using dietlibc
- minor tweaks to initscript

* Thu Apr 27 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-9
- rebuild for fc5

* Wed Mar 29 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-8
- rebuild

* Tue Mar 28 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-7
- move svscanctl alias to /sbin
- scriptlet bug fixes for upgrades
- check if supervise is running before svc -x in initscript del

* Fri Mar 24 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-6
- check for the existance of /log dirs in initscript

* Wed Mar 22 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-5
- move /etc/service to /var/service
- add svscanctl alias
- initscript tweaks: adj. chkconfig to "60 40"
- remove /usr/X11R6/bin from $PATH

* Thu Dec 01 2005 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-4
- Released for production

* Tue Nov 29 2005 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-3
- Move all tools to /sbin (symlinks in /usr/sbin provided)
- Lots of bugfixes in the initscript, and now clearing PATH first
- Add /service as a symlink to /etc/service

* Thu Apr 14 2005 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-2
- Add svstat support for /sbin/service svscan status

* Fri Jul 23 2004 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-1
- Minor spec file tweaks

* Wed May 12 2004 Japheth Cleaver <cleaver@rohan.sdsu.edu> 0.76-0
- New spec file
- Errno patch
- Patch tools, svscan to run from /usr/sbin instead of /command
- svscanboot runs from /etc/service/ instead of /service/
